@@ -1,14 +1,14 @@
 #!/usr/bin/perl
 
 package Devel::PartialDump;
-use Any::Moose;
+use Moose;
 
 use Carp ();
 use Scalar::Util qw(looks_like_number reftype blessed);
 
 use namespace::clean -except => 'meta';
 
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 
 use Sub::Exporter -setup => {
 	exports => [qw(dump warn show show_scalar croak carp confess cluck $default_dumper)],
